// -*- Java -*-
/*!
 * @file  diProviderImpl.java
 * @brief Data Interpretation Module Provider
 * @date  $Date$
 *
 * $Id$
 */

import jp.go.aist.rtm.RTC.DataFlowComponentBase;
import jp.go.aist.rtm.RTC.Manager;
import jp.go.aist.rtm.RTC.port.CorbaConsumer;
import jp.go.aist.rtm.RTC.port.CorbaPort;
import org.omg.PortableServer.POAPackage.ObjectNotActive;
import org.omg.PortableServer.POAPackage.ServantAlreadyActive;
import org.omg.PortableServer.POAPackage.WrongPolicy;
import RTC.ReturnCode_t;
import com.nec.qnes.tms2.RTC.api.TmsSystem;
import com.nec.qnes.tms2.RTC.api.Auth;
import com.nec.qnes.tms2.RTC.api.Location;
import com.nec.qnes.tms2.RTC.api.Tag;
import com.nec.qnes.tms2.RTC.api.TmsMap;
import com.nec.qnes.tms2.RTC.api.Log;

/*!
 * @class diProviderImpl
 * @brief Data Interpretation Module Provider
 *
 */
public class diProviderImpl extends DataFlowComponentBase {

  /*!
   * @brief constructor
   * @param manager Maneger Object
   */
	public diProviderImpl(Manager manager) {  
        super(manager);
        // <rtc-template block="initializer">
        m_diManagementPort = new CorbaPort("diManagement");
        m_diTagPort = new CorbaPort("diTag");
        m_diObjectPort = new CorbaPort("diObject");
        m_diRobotPort = new CorbaPort("diRobot");
        m_sv_tmssystemPort = new CorbaPort("sv_tmssystem");
        m_sv_authPort = new CorbaPort("sv_auth");
        m_sv_locationPort = new CorbaPort("sv_location");
        m_sv_tagPort = new CorbaPort("sv_tag");
        m_sv_tmsmapPort = new CorbaPort("sv_tmsmap");
        m_sv_logPort = new CorbaPort("sv_log");
        // </rtc-template>

    }

    /**
     *
     * The initialize action (on CREATED->ALIVE transition)
     * formaer rtc_init_entry() 
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onInitialize() {
        // Registration: InPort/OutPort/Service
        // <rtc-template block="registration">
        
        // Set service provider to Ports
        try {
        	m_diManagementPort.registerProvider("if_diManagement", "jp::co::ritecs::DataInterpretationModule::RTC::diManagement", m_if_diManagement);
        	m_diTagPort.registerProvider("if_diTag", "jp::co::ritecs::DataInterpretationModule::RTC::diTag", m_if_diTag);
        	m_diObjectPort.registerProvider("if_diObject", "jp::co::ritecs::DataInterpretationModule::RTC::diObject", m_if_diObject);
        	m_diRobotPort.registerProvider("if_diRobot", "jp::co::ritecs::DataInterpretationModule::RTC::diRobot", m_if_diRobot);
        } catch (ServantAlreadyActive e) {
            e.printStackTrace();
        } catch (WrongPolicy e) {
            e.printStackTrace();
        } catch (ObjectNotActive e) {
            e.printStackTrace();
        }
        
        // Set service consumers to Ports
        m_sv_tmssystemPort.registerConsumer("tmssystem", "com::nec::qnes::tms2::RTC::api::TmsSystem", m_tmssystemBase);
        m_sv_authPort.registerConsumer("auth", "com::nec::qnes::tms2::RTC::api::Auth", m_authBase);
        m_sv_locationPort.registerConsumer("location", "com::nec::qnes::tms2::RTC::api::Location", m_locationBase);
        m_sv_tagPort.registerConsumer("tag", "com::nec::qnes::tms2::RTC::api::Tag", m_tagBase);
        m_sv_tmsmapPort.registerConsumer("tmsmap", "com::nec::qnes::tms2::RTC::api::TmsMap", m_tmsmapBase);
        m_sv_logPort.registerConsumer("log", "com::nec::qnes::tms2::RTC::api::Log", m_logBase);
        
        // Set CORBA Service Ports
        addPort(m_diManagementPort);
        addPort(m_diTagPort);
        addPort(m_diObjectPort);
        addPort(m_diRobotPort);
        addPort(m_sv_tmssystemPort);
        addPort(m_sv_authPort);
        addPort(m_sv_locationPort);
        addPort(m_sv_tagPort);
        addPort(m_sv_tmsmapPort);
        addPort(m_sv_logPort);
        // </rtc-template>
        
        // CORBAt@X̏
		/*m_tmssystem	= m_tmssystemBase._ptr();
        m_auth 		= m_authBase._ptr();
        m_location 	= m_locationBase._ptr();
        m_tag 		= m_tagBase._ptr();
        m_tmsmap 	= m_tmsmapBase._ptr();
        m_log		= m_logBase._ptr();*/
        
        // TMSC^[tF[Xݒ
        m_if_diManagement.m_tmssystemBase = m_tmssystemBase;
        m_if_diManagement.m_authBase = m_authBase;
        m_if_diTag.m_tagBase = m_tagBase;
        m_if_diObject.m_locationBase = m_locationBase;
        m_if_diRobot.m_locationBase = m_locationBase;
        
        m_if_diManagement.m_if_diTag = m_if_diTag;
        m_if_diManagement.m_if_diObject = m_if_diObject;
        m_if_diManagement.m_if_diRobot = m_if_diRobot;
        
        System.out.println("Data Interpretation Module Provider Initialized.");
        return super.onInitialize();
    }

    /***
     *
     * The finalize action (on ALIVE->END transition)
     * formaer rtc_exiting_entry()
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onFinalize() {
        return super.onFinalize();
    }

    /***
     *
     * The startup action when ExecutionContext startup
     * former rtc_starting_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onStartup(int ec_id) {
        return super.onStartup(ec_id);
    }

    /***
     *
     * The shutdown action when ExecutionContext stop
     * former rtc_stopping_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onShutdown(int ec_id) {
        return super.onShutdown(ec_id);
    }

    /***
     *
     * The activated action (Active state entry action)
     * former rtc_active_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onActivated(int ec_id) {
        return super.onActivated(ec_id);
    }

    /***
     *
     * The deactivated action (Active state exit action)
     * former rtc_active_exit()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onDeactivated(int ec_id) {
        return super.onDeactivated(ec_id);
    }

    /***
     *
     * The execution action that is invoked periodically
     * former rtc_active_do()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onExecute(int ec_id) {
        return super.onExecute(ec_id);
    }

    /***
     *
     * The aborting action when main logic error occurred.
     * former rtc_aborting_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
  @Override
  public ReturnCode_t onAborting(int ec_id) {
      return super.onAborting(ec_id);
  }

    /***
     *
     * The error action in ERROR state
     * former rtc_error_do()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    public ReturnCode_t onError(int ec_id) {
        return super.onError(ec_id);
    }

    /***
     *
     * The reset action that is invoked resetting
     * This is same but different the former rtc_init_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onReset(int ec_id) {
        return super.onReset(ec_id);
    }

    /***
     *
     * The state update action that is invoked after onExecute() action
     * no corresponding operation exists in OpenRTm-aist-0.2.0
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onStateUpdate(int ec_id) {
        return super.onStateUpdate(ec_id);
    }

    /***
     *
     * The action that is invoked when execution context's rate is changed
     * no corresponding operation exists in OpenRTm-aist-0.2.0
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onRateChanged(int ec_id) {
        return super.onRateChanged(ec_id);
    }
//
    // DataInPort declaration
    // <rtc-template block="inport_declare">
    
    // </rtc-template>

    // DataOutPort declaration
    // <rtc-template block="outport_declare">
    
    // </rtc-template>

    // CORBA Port declaration
    // <rtc-template block="corbaport_declare">
    /*!
     */
    protected CorbaPort m_diManagementPort;
    /*!
     */
    protected CorbaPort m_diTagPort;
    /*!
     */
    protected CorbaPort m_diObjectPort;
    /*!
     */
    protected CorbaPort m_diRobotPort;
    /*!
     */
    protected CorbaPort m_sv_tmssystemPort;
    /*!
     */
    protected CorbaPort m_sv_authPort;
    /*!
     */
    protected CorbaPort m_sv_locationPort;
    /*!
     */
    protected CorbaPort m_sv_tagPort;
    /*!
     */
    protected CorbaPort m_sv_tmsmapPort;
    /*!
     */
    protected CorbaPort m_sv_logPort;
    
    // </rtc-template>

    // Service declaration
    // <rtc-template block="service_declare">
    /*!
     */
    protected diManagementSVC_impl m_if_diManagement = new diManagementSVC_impl();
    /*!
     */
    protected diTagSVC_impl m_if_diTag = new diTagSVC_impl();
    /*!
     */
    protected diObjectSVC_impl m_if_diObject = new diObjectSVC_impl();
    /*!
     */
    protected diRobotSVC_impl m_if_diRobot = new diRobotSVC_impl();
    
    // </rtc-template>

    // Consumer declaration
    // <rtc-template block="consumer_declare">
    protected CorbaConsumer<TmsSystem> m_tmssystemBase = new CorbaConsumer<TmsSystem>(TmsSystem.class);
    /*!
     */
    protected TmsSystem m_tmssystem;
    protected CorbaConsumer<Auth> m_authBase = new CorbaConsumer<Auth>(Auth.class);
    /*!
     */
    protected Auth m_auth;
    protected CorbaConsumer<Location> m_locationBase = new CorbaConsumer<Location>(Location.class);
    /*!
     */
    protected Location m_location;
    protected CorbaConsumer<Tag> m_tagBase = new CorbaConsumer<Tag>(Tag.class);
    /*!
     */
    protected Tag m_tag;
    protected CorbaConsumer<TmsMap> m_tmsmapBase = new CorbaConsumer<TmsMap>(TmsMap.class);
    /*!
     */
    protected TmsMap m_tmsmap;
    protected CorbaConsumer<Log> m_logBase = new CorbaConsumer<Log>(Log.class);
    /*!
     */
    protected Log m_log;
    
    // </rtc-template>


}
